@@ -12,7 +12,6 @@ use flatpak_rs::module::FlatpakModule;
 
 pub const PROJECTS_DB_SUBDIR: &str = "/projects";
 pub const MODULES_DB_SUBDIR: &str = "/modules";
-pub const MANIFESTS_DB_SUBDIR: &str = "/manifests";
 
 pub struct Database {
     pub indexed_projects: BTreeMap<String, SoftwareProject>,
@@ -23,9 +22,6 @@ impl Database {
         if let Err(e) = fs::create_dir_all(Database::get_projects_db_path()) {
             panic!("Could not initialize database directory: {}.", e);
         }
-        if let Err(e) = fs::create_dir_all(Database::get_manifests_db_path()) {
-            panic!("Could not initialize database directory: {}.", e);
-        }
         if let Err(e) = fs::create_dir_all(Database::get_modules_db_path()) {
             panic!("Could not initialize database directory: {}.", e);
         }
@@ -200,10 +196,6 @@ impl Database {
         Database::get_db_path() + PROJECTS_DB_SUBDIR
     }
 
-    pub fn get_manifests_db_path() -> String {
-        Database::get_db_path() + MANIFESTS_DB_SUBDIR
-    }
-
     pub fn get_modules_db_path() -> String {
         Database::get_db_path() + MODULES_DB_SUBDIR
     }
